%define upstream_name Test-TempDir-Tiny
%define upstream_version 0.016

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Temporary directories that stick around when tests fail
License:    ASL 2.0
Group:      Development/Perl
Url:        http://search.cpan.org/dist/%{upstream_name}
Source0:    http://www.cpan.org/modules/by-module/Test/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(B)
BuildRequires: perl(Carp)
BuildRequires: perl(Cwd)
BuildRequires: perl(Exporter) >= 5.570.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Copy)
BuildRequires: perl(File::Path) >= 2.10.0
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Spec::Functions)
BuildRequires: perl(File::Temp)
BuildRequires: perl(Test::More)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This module works with Test::More to create temporary directories that
stick around if tests fail.

It is loosely based on Test::TempDir, but with less complexity, greater
portability and zero non-core dependencies. (Capture::Tiny is
recommended for testing.)

The "tempdir" function is exported by default. When called, it
constructs a directory tree to hold temporary directories.

If the current directory is writable, the root for directories will be
./tmp. Otherwise, a File::Temp directory will be created wherever
temporary directories are stored for your system.

Every *.t file gets its own subdirectory under the root based on the
test filename, but with slashes and periods replaced with underscores.
For example, t/foo.t would get a test-file-specific subdirectory
./tmp/t_foo_t/. Directories created by "tempdir" get put in that
directory. This makes it very easy to find files later if tests fail.

The test-file-specific name is consistent from run-to-run. If an old
directory already exists, it will be removed.

When the test file exits, if all tests passed, then the
test-file-specific directory is recursively removed.

If a test failed and the root directory is ./tmp, the test-file-specific
directory sticks around for inspection. (But if the root is a File::Temp
directory, it is always discarded).

If nothing is left in ./tmp (i.e. no other test file failed), then ./tmp
is cleaned up as well.

This module attempts to avoid race conditions due to parallel testing.
In extreme cases, the test-file-specific subdirectory might be created
as a regular File::Temp directory rather than in ./tmp. In such a case,
a warning will be issued.

%prep
%autosetup -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make

%check
%make test

%install
%makeinstall_std

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Sun Jun 19 2016 pterjan <pterjan> 0.16.0-2.mga6
+ Revision: 1034654
- Rebuild for perl 5.22.2

* Fri Apr 15 2016 shlomif <shlomif> 0.16.0-1.mga6
+ Revision: 1002317
- update to 0.016

* Thu Feb 18 2016 umeabot <umeabot> 0.4.0-2.mga6
+ Revision: 966541
- Mageia 6 Mass Rebuild

* Sat Jun 27 2015 sander85 <sander85> 0.4.0-1.mga6
+ Revision: 845894
- imported package perl-Test-TempDir-Tiny

